/****************************************************************************
FILE          : qnx-pulse-server.c
LAST REVISED  : 2009-12-02
SUBJECT       : Program to demonstrate QNX's message passing API.

This program is a server that waits for pulses. It then just prints out information about the
pulse. Had this been a "real" program it would do something useful in response to each pulse
received.

     Peter C. Chapin
     Computer Information Systems Department
     Vermont Technical College
     Williston, VT 05061
     PChapin@vtc.vsc.edu
****************************************************************************/

#include <errno.h>
#include <stdio.h>
#include <string.h>
#include <sys/netmgr.h>
#include <sys/neutrino.h>

//
// The main program allocates the resources needed and acts as the server.
//
void *server( void *arg )
{
    int   channel_id;
    struct _pulse thePulse;

    // Create a channel.
    channel_id = ChannelCreate( 0 );
    printf( "Server: Created channel %d\n", channel_id );

    while( 1 ) {
        // Get a client request, process it, and send back a reply.
        if( MsgReceivePulse( channel_id, &thePulse, sizeof(struct _pulse), NULL ) == -1 ) {
            printf( "%s\n", strerror( errno ) );
        }
        printf( "Server: Code: %d Value: %d\n", thePulse.code, thePulse.value.sival_int );
    }

    // Clean up the channel.
    ChannelDestroy( channel_id );
    return NULL;
}
